package de.kif.common

import com.soywiz.klock.*
import com.soywiz.klock.locale.german
import kotlin.math.ceil

fun formatDateTime(unix: Long, timezone: Long) =
    DateFormat("EEEE, d. MMMM y HH:mm")
        .withLocale(KlockLocale.german)
        .format(DateTimeTz.utc(DateTime(unix), TimezoneOffset(timezone.toDouble())))

fun formatDate(unix: Long, timezone: Long) =
    DateFormat("EEEE, d. MMMM y")
        .withLocale(KlockLocale.german)
        .format(DateTimeTz.utc(DateTime(unix), TimezoneOffset(timezone.toDouble())))

fun formatDateWithoutYear(unix: Long, timezone: Long) =
    DateFormat("EEEE, d. MMMM")
        .withLocale(KlockLocale.german)
        .format(DateTimeTz.utc(DateTime(unix), TimezoneOffset(timezone.toDouble())))

fun formatTime(unix: Long, timezone: Long) =
    DateFormat("HH:mm")
        .withLocale(KlockLocale.german)
        .format(DateTimeTz.utc(DateTime(unix), TimezoneOffset(timezone.toDouble())))

fun formatTimeDiff(time: Long, now: Long, timezone: Long): String {
    var dt = ceil(((time - now) / 1000) / 60.0).toLong()

    val minutes = dt % 60
    dt /= 60
    val hours = dt % 24
    dt /= 24
    val days = dt

    return when {
        days > 1L -> "in $days Tagen"
        days > 0L -> "morgen"
        hours > 1L -> {
            val nowHour = DateFormat("HH")
                .withLocale(KlockLocale.german)
                .format(DateTimeTz.utc(DateTime(time), TimezoneOffset(timezone.toDouble()))).toIntOrNull() ?: 0

            val ht = DateFormat("HH:mm")
                .withLocale(KlockLocale.german)
                .format(DateTimeTz.utc(DateTime(time), TimezoneOffset(timezone.toDouble())))

            if ((ht.substringBefore(":").toIntOrNull() ?: 0) < nowHour) {
                "morgen"
            } else "um $ht"
        }
        hours > 0L -> "in " + hours.toTimeString() + ":" + minutes.toTimeString()
        minutes > 1L -> "in 00:" + minutes.toTimeString()
        else -> "in > 1 Minute"
    }
}

@Suppress("NOTHING_TO_INLINE")
private inline fun Number.toTimeString() = toString().padStart(2, '0')
